pub struct ThenTry<E, First: Decoder, Second: Decoder, Fun: FnOnce(First::Value) -> Result<Second, E>>(/* private fields */)
where
E: From<First::Error> + From<Second::Error>;Trait Implementations
Sourceimpl<E, First: Debug + Decoder, Second: Debug + Decoder, Fun: Debug + FnOnce(First::Value) -> Result<Second, E>> Debug for ThenTry<E, First, Second, Fun>
impl<E, First: Debug + Decoder, Second: Debug + Decoder, Fun: Debug + FnOnce(First::Value) -> Result<Second, E>> Debug for ThenTry<E, First, Second, Fun>
Sourceimpl<E, First: Decoder, Second: Decoder, Fun: FnOnce(First::Value) -> Result<Second, E>> Decoder for ThenTry<E, First, Second, Fun>
impl<E, First: Decoder, Second: Decoder, Fun: FnOnce(First::Value) -> Result<Second, E>> Decoder for ThenTry<E, First, Second, Fun>
Sourcefn decode_chunk(&mut self, bytes: &mut &[u8]) -> Result<(), Self::Error>
fn decode_chunk(&mut self, bytes: &mut &[u8]) -> Result<(), Self::Error>
Processes nex chunk of bytes and updates the cursor. Read more
Sourcefn end(self) -> Result<Self::Value, Self::Error>
fn end(self) -> Result<Self::Value, Self::Error>
Called when decoding has ended or there are no more bytes. Read more
Sourcefn bytes_received(&mut self, bytes: &[u8]) -> Result<usize, Self::Error>
fn bytes_received(&mut self, bytes: &[u8]) -> Result<usize, Self::Error>
Processes nex chunk of bytes without updating the cursor. Read more
Sourcefn then<R: Decoder, F: FnOnce(Self::Value) -> R>(
self,
fun: F,
) -> Then<Self, R, F>
fn then<R: Decoder, F: FnOnce(Self::Value) -> R>( self, fun: F, ) -> Then<Self, R, F>
Chains another decoder after this one finishes such that the value of this one is used to
initialize the next one.
Sourcefn then_try<E, R: Decoder, F: FnOnce(Self::Value) -> Result<R, E>>(
self,
fun: F,
) -> ThenTry<E, Self, R, F>
fn then_try<E, R: Decoder, F: FnOnce(Self::Value) -> Result<R, E>>( self, fun: F, ) -> ThenTry<E, Self, R, F>
Chains another decoder after this one finishes such that the value of this one is used to
initialize the next one. Read more
Sourcefn chain<D: Decoder>(self, following: D) -> Chain<Self, D>
fn chain<D: Decoder>(self, following: D) -> Chain<Self, D>
Chains another decoder after this one to decode two values.
Sourcefn wrap_sub_decode<F: FnOnce() -> ControlFlow<Result<(), Self::Error>, Infallible>>(
f: F,
) -> Result<(), Self::Error>
fn wrap_sub_decode<F: FnOnce() -> ControlFlow<Result<(), Self::Error>, Infallible>>( f: F, ) -> Result<(), Self::Error>
Helper for using sub_decode. Read more