pub struct Then<A, B, F> { /* private fields */ }Trait Implementations
Sourceimpl<A: Encoder, B: Encoder, F: FnMut() -> B> Encoder for Then<A, B, F>
impl<A: Encoder, B: Encoder, F: FnMut() -> B> Encoder for Then<A, B, F>
Sourcefn next(&mut self) -> bool
fn next(&mut self) -> bool
Advances the state to get the next chunk of encoded bytes. Read more
Sourcefn track_position(self) -> EncoderPositionTracker<Self>
fn track_position(self) -> EncoderPositionTracker<Self>
Returns a wrapper that tracks the position of processed bytes. Read more
fn write_to_slice(self, buf: &mut &mut [u8]) -> Result<(), BufferOverflow>
Sourcefn write_to_vec(self, buf: &mut Vec<u8>)
fn write_to_vec(self, buf: &mut Vec<u8>)
Available on crate feature
alloc only.Writes all encoded bytes to a vec. Read more
Sourcefn write_all_sync<W: Write + BufWrite>(self, writer: W) -> Result<()>
fn write_all_sync<W: Write + BufWrite>(self, writer: W) -> Result<()>
Available on crate feature
std only.Writes all encoded bytes to the
std writer.Sourcefn write_all_sync_lgio<W: BufWrite>(
self,
writer: W,
) -> Result<(), W::WriteError>
fn write_all_sync_lgio<W: BufWrite>( self, writer: W, ) -> Result<(), W::WriteError>
Available on crate feature
lgio only.Writes all encoded bytes to the
std writer.Sourcefn write_all_tokio<W: AsyncWrite + BufWrite>(
self,
writer: W,
) -> TokioEncodeFuture<W, Self> ⓘ
fn write_all_tokio<W: AsyncWrite + BufWrite>( self, writer: W, ) -> TokioEncodeFuture<W, Self> ⓘ
Available on crate feature
tokio only.Writes all encoded bytes to the
tokio async writer. Read moreSourcefn write_all_async_std<W: Write + BufWrite>(
self,
writer: W,
) -> AsyncStdEncodeFuture<W, Self> ⓘ
fn write_all_async_std<W: Write + BufWrite>( self, writer: W, ) -> AsyncStdEncodeFuture<W, Self> ⓘ
Available on crate feature
async-std only.Writes all encoded bytes to the
async-std async writer. Read moreSourcefn write_all_futures_0_3<W: AsyncWrite + BufWrite>(
self,
writer: W,
) -> Futures0Dot3EncodeFuture<W, Self> ⓘ
fn write_all_futures_0_3<W: AsyncWrite + BufWrite>( self, writer: W, ) -> Futures0Dot3EncodeFuture<W, Self> ⓘ
Available on crate feature
futures_0_3 only.Writes all encoded bytes to the
futures 0.3 async writer. Read moreAuto Trait Implementations
impl<A, B, F> Freeze for Then<A, B, F>
impl<A, B, F> RefUnwindSafe for Then<A, B, F>
impl<A, B, F> Send for Then<A, B, F>
impl<A, B, F> Sync for Then<A, B, F>
impl<A, B, F> Unpin for Then<A, B, F>
impl<A, B, F> UnwindSafe for Then<A, B, F>