pub enum ReadError<Decode, Read = Error> {
    Read(Read),
    Decode(Decode),
}
Returned when either reading or decoding fails.

Note that the Read type param only defaults to std::io::Error with std feature enabled.

Variants



Read(Read)

Reading from a reader failed.



Decode(Decode)

Decoding the value failed.

Implementations

source

impl<D, R> ReadError<D, R>

source

pub fn convert_either<E>(self) -> E
where D: Into<E>, R: Into<E>,

Converts the inner errors to another type E.

source

pub fn map_read<E, F>(self, map: F) -> ReadError<D, E>
where F: FnOnce(R) -> E,

Converts the read error using a closure.

This is analogous to Result::map/Result::map_err and leaves Decode intact.

source

pub fn map_decode<E, F>(self, map: F) -> ReadError<E, R>
where F: FnOnce(D) -> E,

Converts the decode error using a closure.

This is analogous to Result::map/Result::map_err and leaves Read intact.

source

impl<E> ReadError<E, Infallible>

source

pub fn into_decode(self) -> E

Statically proves that reading is infallible and converts to decode error.

source

impl<E> ReadError<Infallible, E>

source

pub fn into_read(self) -> E

Statically proves that decoding is infallible and converts to read error.