Struct AssumeBuffered

pub struct AssumeBuffered<T> { /* private fields */ }
Wrapper for external types that are known to be buffered.

Downstream users may use this to satisfy the constraint of write_ methods when they themselves can’t implement BufWrite for types from external crates due to orphan rules.

Implementations

Source

impl<T> AssumeBuffered<T>

pub fn new(writer: T) -> Self

Available on crate features std or tokio or async-std or futures_0_3 only.
pub fn inner(&self) -> &T

Available on crate features std or tokio or async-std or futures_0_3 only.
pub fn inner_mut(&mut self) -> &mut T

Available on crate features std or tokio or async-std or futures_0_3 only.
pub fn into_inner(self) -> T

Available on crate features std or tokio or async-std or futures_0_3 only.