Enum push_decode::ReadError
source · pub enum ReadError<Decode, Read = Error> {
Read(Read),
Decode(Decode),
}Expand description
Returned when either reading or decoding fails.
Note that the Read type param only defaults to std::io::Error with std feature enabled.
Variants
Implementations
sourceimpl<D, R> ReadError<D, R>
impl<D, R> ReadError<D, R>
sourcepub fn convert_either<E>(self) -> E
pub fn convert_either<E>(self) -> E
Converts the inner errors to another type E.
sourcepub fn map_read<E, F>(self, map: F) -> ReadError<D, E>where
F: FnOnce(R) -> E,
pub fn map_read<E, F>(self, map: F) -> ReadError<D, E>where
F: FnOnce(R) -> E,
Converts the read error using a closure.
This is analogous to Result::map/Result::map_err and leaves Decode intact.
sourcepub fn map_decode<E, F>(self, map: F) -> ReadError<E, R>where
F: FnOnce(D) -> E,
pub fn map_decode<E, F>(self, map: F) -> ReadError<E, R>where
F: FnOnce(D) -> E,
Converts the decode error using a closure.
This is analogous to Result::map/Result::map_err and leaves Read intact.
sourceimpl<E> ReadError<E, Infallible>
impl<E> ReadError<E, Infallible>
sourcepub fn into_decode(self) -> E
pub fn into_decode(self) -> E
Statically proves that reading is infallible and converts to decode error.