Trait push_decode::BufWrite
source · pub trait BufWrite { }Available on crate features
std or tokio or async-std or futures_0_3 only.Expand description
Marker trait for writers that are either buffered or don’t incur the cost of context switch.
The trait should be implemented for types which don’t incur a (significant) performance penalty when writing short chunks of data.
Implementations on Foreign Types
impl<'a, T: BufWrite> BufWrite for &mut T
impl<T: Write> BufWrite for BufWriter<T>
Available on crate feature
std only.impl<T: Write> BufWrite for BufWriter<T>
Available on crate feature
async-std only.impl<T: AsyncWrite> BufWrite for BufWriter<T>
Available on crate feature
tokio only.